
# DeutschlandAPI SDK

This SDK helps to access the [DeutschlandAPI](https://deutschland-api.dev)

## Usage

The following example shows how you initialize the client:

```python
from sdk.client import Client

client = Client.build()

// @TODO use the client
```
